@@ -147,7 +147,7 @@ class QualityProcessTemplate(Object):
 
         return steps
 
-    def new(self, title, description=None, owner=None, number_format=None):
+    def new(self, title, description=None, owner=None, number_format=None, prefix=None):
 
         """
         Create a new Quality record from this template.
@@ -165,8 +165,20 @@ class QualityProcessTemplate(Object):
         Returns: QualityProcess object
         """
 
+        number_format = number_format or self.default_number_format
+
+        if len(number_format.prefixes)>1 and not prefix:
+            raise ValueError(f"Selected number format has multiple prefixes. Add a `prefix` argument with one of the following values: \"{'\", \"'.join([x['value'] for x in number_format.prefixes])}\"")
+        elif len(number_format.prefixes)>1:
+            prefix_dict = {x["value"]: x["guid"] for x in number_format.prefixes}
+            if prefix not in prefix_dict:
+                raise ValueError(f"`prefix` must be one of the following for this numbering format: \"{'\", \"'.join([x['value'] for x in number_format.prefixes])}\"")
+            prefix_id=prefix_dict[prefix]
+        else:
+            prefix_id=number_format.prefixes[0]["guid"]
+
+
         data = {  
-           "description":description or "",
            "name":title,
            "owner":{  
               "guid": owner.guid if owner else self._client.me.guid
@@ -175,12 +187,13 @@ class QualityProcessTemplate(Object):
               "guid": self.guid,
               "numberFormat":{  
                  "prefix":{  
-                    "guid": number_format.guid if number_format else self.__dict__['defaultNumberFormat']['guid'] 
+                    "guid": prefix_id
                  }
               }
-           },
-           "type":""
+           }
         }
+        if description:
+            data["description"]=description
 
         new_qp = self._client.QualityProcess(**data)
         new_qp.create()
